==> welltested-0.1.3.tar.gz: lib/builder.dart <==
/*
 * Created on Tue Mar 07 2023
 *
 * Copyright (C) 2023 PixelApps - All Rights Reserved
 * The code in this file is Intellectutal Property of PixelApps
 * and can't be edited, redistributed or used without a valid license of it's product (Welltested)[https://welltested.ai]
 */
import 'package:build/build.dart';
import 'package:source_gen/source_gen.dart';
import 'package:welltested/generators/placeholder_generator.dart';
import 'package:welltested/generators/saver_generator.dart';
import 'package:welltested/generators/welltested_generator.dart';
import 'package:welltested/generators/welltested_save_generator.dart';

Builder welltestedGenerator(BuilderOptions options) {
  ///TODO: Clean this code
  Map<String, String> possiblePaths = {};
  List.generate(100, (index) => index).forEach(
      (e) => possiblePaths['lib/{{$e}}.dart'] = 'test/{{$e}}/$e.wt.dart');
  return LibraryBuilder(WelltestedGenerator(),
      generatedExtension: ".wt.dart",
      allowSyntaxErrors: true,
      options: BuilderOptions({"build_extensions": possiblePaths}));
}

Builder welltestedSaveGenerator(BuilderOptions options) {
  return LibraryBuilder(WelltestedSaveGenerator(),
      generatedExtension: ".hello.dart", allowSyntaxErrors: true);
}

Builder placeholderGenerator(BuilderOptions options) {
  return LibraryBuilder(PlaceHolderGenerator(),
      generatedExtension: ".mock_test.dart");
}

Builder saverGenerator(BuilderOptions options) {
  return LibraryBuilder(SaverGenerator(),
      options: BuilderOptions({
        "build_extensions": {
          '.wt.dart': '.hello.dart',
        }
      }));
}

==> welltested-1.0.5.tar.gz: lib/builder.dart <==
/*
 * Created on May 1st 2023
 *
 * Copyright (C) 2023 Welltested AI - All Rights Reserved
 * The code in this file is Intellectutal Property of Welltested AI.
 * and can't be edited, redistributed or used without a valid license of it's product (Welltested)[https://welltested.ai]
 */
import 'package:build/build.dart';
import 'package:source_gen/source_gen.dart';
import 'package:welltested/generators/placeholder_generator.dart';
import 'package:welltested/generators/save_builder.dart';
import 'package:welltested/generators/saver_generator.dart';
import 'package:welltested/generators/welltested_generator.dart';

Builder welltestedGenerator(BuilderOptions options) {
  ///TODO: Clean this code
  Map<String, String> possiblePaths = {};
  List.generate(100, (index) => index).forEach(
      (e) => possiblePaths['lib/{{$e}}.dart'] = 'test/{{$e}}/$e.wt.dart');
  return LibraryBuilder(WelltestedGenerator(),
      generatedExtension: ".wt.dart",
      allowSyntaxErrors: true,
      options: BuilderOptions({"build_extensions": possiblePaths}));
}

Builder welltestedSaveGenerator(BuilderOptions options) => SaveBuilder();

Builder placeholderGenerator(BuilderOptions options) {
  return LibraryBuilder(PlaceHolderGenerator(),
      generatedExtension: ".mock_test.dart");
}

Builder saverGenerator(BuilderOptions options) {
  return LibraryBuilder(SaverGenerator(),
      allowSyntaxErrors: true,
      options: BuilderOptions({
        "build_extensions": {
          '.wt.dart': '.hello.dart',
        }
      }));
}
